CallStateEnum enum
Values
- NONE → const CallStateEnum
- STREAM → const CallStateEnum
- UNMUTED → const CallStateEnum
- MUTED → const CallStateEnum
- CONNECTING → const CallStateEnum
- PROGRESS → const CallStateEnum
- FAILED → const CallStateEnum
- ENDED → const CallStateEnum
- ACCEPTED → const CallStateEnum
- CONFIRMED → const CallStateEnum
- REFER → const CallStateEnum
- HOLD → const CallStateEnum
- UNHOLD → const CallStateEnum
- CALL_INITIATION → const CallStateEnum
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
CallStateEnum> - A constant List of the values in this enum, in order of their declaration.