IceTransportPolicy enum

Possible values for the transport policy to be used when selecting ICE candidates.

See: https://udn.realityripple.com/docs/Web/API/RTCConfiguration

Inheritance
Available extensions

Values

ALL → const IceTransportPolicy

All ICE candidates will be considered. This is the default if not specified explicitly.

RELAY → const IceTransportPolicy

Only ICE candidates whose IP addresses are being relayed, such as those being passed through a TURN server, will be considered.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<IceTransportPolicy>
A constant List of the values in this enum, in order of their declaration.